Class: Google::Apis::NetworkconnectivityV1alpha1::AllocationOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1alpha1/classes.rb,
lib/google/apis/networkconnectivity_v1alpha1/representations.rb,
lib/google/apis/networkconnectivity_v1alpha1/representations.rb

Overview

Range auto-allocation options, to be optionally used when CIDR block is not explicitly set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationOptions

Returns a new instance of AllocationOptions.



43
44
45
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 43

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocation_strategyString

Optional. Allocation strategy. Not setting this field when the allocation is requested means an implementation defined strategy is used. Corresponds to the JSON property allocationStrategy

Returns:

  • (String)


34
35
36
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 34

def allocation_strategy
  @allocation_strategy
end

#first_available_ranges_lookup_sizeFixnum

Optional. This field must be set only when allocation_strategy is set to RANDOM_FIRST_N_AVAILABLE. The value should be the maximum expected parallelism of range creation requests issued to the same space of peered netwroks. Corresponds to the JSON property firstAvailableRangesLookupSize

Returns:

  • (Fixnum)


41
42
43
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 41

def first_available_ranges_lookup_size
  @first_available_ranges_lookup_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48
49
50
51
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 48

def update!(**args)
  @allocation_strategy = args[:allocation_strategy] if args.key?(:allocation_strategy)
  @first_available_ranges_lookup_size = args[:first_available_ranges_lookup_size] if args.key?(:first_available_ranges_lookup_size)
end