Class: Google::Apis::NetworkconnectivityV1alpha1::Hub

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1alpha1/classes.rb,
lib/google/apis/networkconnectivity_v1alpha1/representations.rb,
lib/google/apis/networkconnectivity_v1alpha1/representations.rb

Overview

Network Connectivity Center is a hub-and-spoke abstraction for network connectivity management in Google Cloud. It reduces operational complexity through a simple, centralized connectivity management model. Following is the resource message of a hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Hub

Returns a new instance of Hub.



495
496
497
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Time when the Hub was created. Corresponds to the JSON property createTime

Returns:

  • (String)


454
455
456
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 454

def create_time
  @create_time
end

#descriptionString

Short description of the hub resource. Corresponds to the JSON property description

Returns:

  • (String)


459
460
461
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 459

def description
  @description
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


464
465
466
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 464

def labels
  @labels
end

#nameString

Immutable. The name of a Hub resource. Corresponds to the JSON property name

Returns:

  • (String)


469
470
471
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 469

def name
  @name
end

#spokesArray<String>

Output only. A list of the URIs of all attached spokes. This field is deprecated and will not be included in future API versions. Call ListSpokes on each region instead. Corresponds to the JSON property spokes

Returns:

  • (Array<String>)


476
477
478
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 476

def spokes
  @spokes
end

#stateString

Output only. The current lifecycle state of this Hub. Corresponds to the JSON property state

Returns:

  • (String)


481
482
483
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 481

def state
  @state
end

#unique_idString

Output only. Google-generated UUID for this resource. This is unique across all Hub resources. If a Hub resource is deleted and another with the same name is created, it gets a different unique_id. Corresponds to the JSON property uniqueId

Returns:

  • (String)


488
489
490
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 488

def unique_id
  @unique_id
end

#update_timeString

Time when the Hub was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


493
494
495
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 493

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



500
501
502
503
504
505
506
507
508
509
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 500

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spokes = args[:spokes] if args.key?(:spokes)
  @state = args[:state] if args.key?(:state)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end