Class: Google::Apis::NetworkconnectivityV1alpha1::Migration
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1alpha1::Migration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1alpha1/classes.rb,
lib/google/apis/networkconnectivity_v1alpha1/representations.rb,
lib/google/apis/networkconnectivity_v1alpha1/representations.rb
Overview
Specification for migration with source and target resource names.
Instance Attribute Summary collapse
-
#source ⇒ String
Immutable.
-
#target ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Migration
constructor
A new instance of Migration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Migration
Returns a new instance of Migration.
854 855 856 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source ⇒ String
Immutable. Resource path as an URI of the source resource, for example a
subnet. The project for the source resource should match the project for the
InternalRange. An example: /projects/project/regions/region/subnetworks/
subnet
Corresponds to the JSON property source
845 846 847 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 845 def source @source end |
#target ⇒ String
Immutable. Resource path of the target resource. The target project can be
different, as in the cases when migrating to peer networks. For example: /
projects/project/regions/region/subnetworks/subnet
Corresponds to the JSON property target
852 853 854 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 852 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
859 860 861 862 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/classes.rb', line 859 def update!(**args) @source = args[:source] if args.key?(:source) @target = args[:target] if args.key?(:target) end |