Class: Google::Apis::NetworkconnectivityV1alpha1::NetworkconnectivityService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::NetworkconnectivityV1alpha1::NetworkconnectivityService
- Defined in:
- lib/google/apis/networkconnectivity_v1alpha1/service.rb
Overview
Network Connectivity API
This API enables connectivity with and between Google Cloud resources.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://networkconnectivity.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_global_hub(parent, hub_object = nil, hub_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new Network Connectivity Center hub in the specified project.
-
#create_project_location_internal_range(parent, internal_range_object = nil, internal_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new internal range in a given project and location.
-
#create_project_location_spoke(parent, spoke_object = nil, request_id: nil, spoke_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a Network Connectivity Center spoke.
-
#delete_project_location_global_hub(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center hub.
-
#delete_project_location_internal_range(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a single internal range.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Deletes a long-running operation.
-
#delete_project_location_spoke(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center spoke.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Location
Gets information about a location.
-
#get_project_location_global_hub(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Hub
Gets details about a Network Connectivity Center hub.
-
#get_project_location_global_hub_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource.
-
#get_project_location_internal_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::InternalRange
Gets details of a single internal range.
-
#get_project_location_internal_range_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_spoke(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Spoke
Gets details about a Network Connectivity Center spoke.
-
#get_project_location_spoke_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource.
-
#initialize ⇒ NetworkconnectivityService
constructor
A new instance of NetworkconnectivityService.
-
#list_project_location_global_hubs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse
Lists the Network Connectivity Center hubs associated with a given project.
-
#list_project_location_internal_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse
Lists internal ranges in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_spokes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse
Lists the Network Connectivity Center spokes in a specified project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_global_hub(name, hub_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the description and/or labels of a Network Connectivity Center hub.
-
#patch_project_location_internal_range(name, internal_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a single internal range.
-
#patch_project_location_spoke(name, spoke_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a Network Connectivity Center spoke.
-
#set_hub_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource.
-
#set_internal_range_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource.
-
#set_spoke_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource.
-
#test_hub_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_internal_range_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_spoke_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ NetworkconnectivityService
Returns a new instance of NetworkconnectivityService.
47 48 49 50 51 52 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-networkconnectivity_v1alpha1', client_version: Google::Apis::NetworkconnectivityV1alpha1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
845 846 847 848 849 850 851 852 853 854 855 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 845 def cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:cancel', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningCancelOperationRequest::Representation command.request_object = google_longrunning_cancel_operation_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Empty::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_global_hub(parent, hub_object = nil, hub_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new Network Connectivity Center hub in the specified project.
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 175 def create_project_location_global_hub(parent, hub_object = nil, hub_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/hubs', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Hub::Representation command.request_object = hub_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['hubId'] = hub_id unless hub_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_internal_range(parent, internal_range_object = nil, internal_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new internal range in a given project and location.
514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 514 def create_project_location_internal_range(parent, internal_range_object = nil, internal_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/internalRanges', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::InternalRange::Representation command.request_object = internal_range_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['internalRangeId'] = internal_range_id unless internal_range_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_spoke(parent, spoke_object = nil, request_id: nil, spoke_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a Network Connectivity Center spoke.
1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1005 def create_project_location_spoke(parent, spoke_object = nil, request_id: nil, spoke_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/spokes', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Spoke::Representation command.request_object = spoke_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['spokeId'] = spoke_id unless spoke_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_global_hub(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center hub.
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 221 def delete_project_location_global_hub(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_internal_range(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a single internal range.
559 560 561 562 563 564 565 566 567 568 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 559 def delete_project_location_internal_range(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
880 881 882 883 884 885 886 887 888 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 880 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Empty::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_spoke(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center spoke.
1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1051 def delete_project_location_spoke(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Location::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_hub(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Hub
Gets details about a Network Connectivity Center hub.
252 253 254 255 256 257 258 259 260 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 252 def get_project_location_global_hub(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Hub::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Hub command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_hub_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
296 297 298 299 300 301 302 303 304 305 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 296 def get_project_location_global_hub_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_internal_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::InternalRange
Gets details of a single internal range.
590 591 592 593 594 595 596 597 598 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 590 def get_project_location_internal_range(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::InternalRange::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::InternalRange command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_internal_range_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 634 def get_project_location_internal_range_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
911 912 913 914 915 916 917 918 919 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 911 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_spoke(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Spoke
Gets details about a Network Connectivity Center spoke.
1082 1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1082 def get_project_location_spoke(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Spoke::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Spoke command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_spoke_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1126 def get_project_location_spoke_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_global_hubs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse
Lists the Network Connectivity Center hubs associated with a given project.
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 335 def list_project_location_global_hubs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/hubs', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_internal_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse
Lists internal ranges in a given project and location.
673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 673 def list_project_location_internal_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/internalRanges', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
956 957 958 959 960 961 962 963 964 965 966 967 968 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 956 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/operations', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_spokes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse
Lists the Network Connectivity Center spokes in a specified project and location.
1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1166 def list_project_location_spokes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/spokes', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/locations', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_global_hub(name, hub_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the description and/or labels of a Network Connectivity Center hub.
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 388 def patch_project_location_global_hub(name, hub_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Hub::Representation command.request_object = hub_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_internal_range(name, internal_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a single internal range.
727 728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 727 def patch_project_location_internal_range(name, internal_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::InternalRange::Representation command.request_object = internal_range_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_spoke(name, spoke_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a Network Connectivity Center spoke.
1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1219 def patch_project_location_spoke(name, spoke_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Spoke::Representation command.request_object = spoke_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_hub_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 427 def set_hub_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_internal_range_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
766 767 768 769 770 771 772 773 774 775 776 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 766 def set_internal_range_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_spoke_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1258 def set_spoke_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_hub_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 466 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_internal_range_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
805 806 807 808 809 810 811 812 813 814 815 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 805 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_spoke_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1297 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |