Class: Google::Apis::NetworkconnectivityV1alpha1::NetworkconnectivityService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::NetworkconnectivityV1alpha1::NetworkconnectivityService
- Defined in:
- lib/google/apis/networkconnectivity_v1alpha1/service.rb
Overview
Network Connectivity API
This API enables connectivity with and between Google Cloud resources.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://networkconnectivity.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_global_hub(parent, hub_object = nil, hub_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new Network Connectivity Center hub in the specified project.
-
#create_project_location_internal_range(parent, internal_range_object = nil, internal_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new internal range in a given project and location.
-
#create_project_location_spoke(parent, spoke_object = nil, request_id: nil, spoke_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a Network Connectivity Center spoke.
-
#delete_project_location_global_hub(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center hub.
-
#delete_project_location_internal_range(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a single internal range.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Deletes a long-running operation.
-
#delete_project_location_spoke(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center spoke.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Location
Gets information about a location.
-
#get_project_location_global_hub(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Hub
Gets details about a Network Connectivity Center hub.
-
#get_project_location_global_hub_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource.
-
#get_project_location_internal_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::InternalRange
Gets details of a single internal range.
-
#get_project_location_internal_range_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_spoke(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Spoke
Gets details about a Network Connectivity Center spoke.
-
#get_project_location_spoke_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource.
-
#initialize ⇒ NetworkconnectivityService
constructor
A new instance of NetworkconnectivityService.
-
#list_project_location_global_hubs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse
Lists the Network Connectivity Center hubs associated with a given project.
-
#list_project_location_internal_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse
Lists internal ranges in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_spokes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse
Lists the Network Connectivity Center spokes in a specified project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_global_hub(name, hub_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the description and/or labels of a Network Connectivity Center hub.
-
#patch_project_location_internal_range(name, internal_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a single internal range.
-
#patch_project_location_spoke(name, spoke_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a Network Connectivity Center spoke.
-
#set_hub_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource.
-
#set_internal_range_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource.
-
#set_spoke_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource.
-
#test_hub_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_internal_range_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_spoke_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ NetworkconnectivityService
Returns a new instance of NetworkconnectivityService.
47 48 49 50 51 52 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-networkconnectivity_v1alpha1', client_version: Google::Apis::NetworkconnectivityV1alpha1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
836 837 838 839 840 841 842 843 844 845 846 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 836 def cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:cancel', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningCancelOperationRequest::Representation command.request_object = google_longrunning_cancel_operation_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Empty::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_global_hub(parent, hub_object = nil, hub_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new Network Connectivity Center hub in the specified project.
166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 166 def create_project_location_global_hub(parent, hub_object = nil, hub_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/hubs', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Hub::Representation command.request_object = hub_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['hubId'] = hub_id unless hub_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_internal_range(parent, internal_range_object = nil, internal_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a new internal range in a given project and location.
505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 505 def create_project_location_internal_range(parent, internal_range_object = nil, internal_range_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/internalRanges', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::InternalRange::Representation command.request_object = internal_range_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['internalRangeId'] = internal_range_id unless internal_range_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_spoke(parent, spoke_object = nil, request_id: nil, spoke_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Creates a Network Connectivity Center spoke.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 996 def create_project_location_spoke(parent, spoke_object = nil, request_id: nil, spoke_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/spokes', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Spoke::Representation command.request_object = spoke_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['spokeId'] = spoke_id unless spoke_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_global_hub(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center hub.
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 212 def delete_project_location_global_hub(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_internal_range(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a single internal range.
550 551 552 553 554 555 556 557 558 559 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 550 def delete_project_location_internal_range(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
871 872 873 874 875 876 877 878 879 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 871 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Empty::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_spoke(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Deletes a Network Connectivity Center spoke.
1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1042 def delete_project_location_spoke(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Location::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_hub(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Hub
Gets details about a Network Connectivity Center hub.
243 244 245 246 247 248 249 250 251 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 243 def get_project_location_global_hub(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Hub::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Hub command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_global_hub_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
287 288 289 290 291 292 293 294 295 296 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 287 def get_project_location_global_hub_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_internal_range(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::InternalRange
Gets details of a single internal range.
581 582 583 584 585 586 587 588 589 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 581 def get_project_location_internal_range(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::InternalRange::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::InternalRange command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_internal_range_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
625 626 627 628 629 630 631 632 633 634 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 625 def get_project_location_internal_range_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
902 903 904 905 906 907 908 909 910 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 902 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_spoke(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Spoke
Gets details about a Network Connectivity Center spoke.
1073 1074 1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1073 def get_project_location_spoke(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Spoke::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Spoke command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_spoke_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1117 def get_project_location_spoke_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_global_hubs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse
Lists the Network Connectivity Center hubs associated with a given project.
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 326 def list_project_location_global_hubs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/hubs', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListHubsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_internal_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse
Lists internal ranges in a given project and location.
664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 664 def list_project_location_internal_ranges(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/internalRanges', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListInternalRangesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
947 948 949 950 951 952 953 954 955 956 957 958 959 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 947 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/operations', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_spokes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse
Lists the Network Connectivity Center spokes in a specified project and location.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1157 def list_project_location_spokes(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/spokes', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListSpokesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 117 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/locations', ) command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_global_hub(name, hub_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the description and/or labels of a Network Connectivity Center hub.
379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 379 def patch_project_location_global_hub(name, hub_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Hub::Representation command.request_object = hub_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_internal_range(name, internal_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a single internal range.
718 719 720 721 722 723 724 725 726 727 728 729 730 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 718 def patch_project_location_internal_range(name, internal_range_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::InternalRange::Representation command.request_object = internal_range_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_spoke(name, spoke_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation
Updates the parameters of a Network Connectivity Center spoke.
1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1210 def patch_project_location_spoke(name, spoke_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha1/{+name}', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::Spoke::Representation command.request_object = spoke_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_hub_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 418 def set_hub_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_internal_range_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
757 758 759 760 761 762 763 764 765 766 767 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 757 def set_internal_range_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_spoke_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1249 def set_spoke_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::Policy::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_hub_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 457 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_internal_range_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
796 797 798 799 800 801 802 803 804 805 806 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 796 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_spoke_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 |
# File 'lib/google/apis/networkconnectivity_v1alpha1/service.rb', line 1288 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NetworkconnectivityV1alpha1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |